@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 # pylint: skip-file
 
-from projectq.cengines import MainEngine
-from projectq.ops import All, H, X, Measure
-from projectq.meta import Compute, Uncompute, Dagger
-from projectq.libs.revkit import PhaseOracle, PermutationOracle
+"""Example of a 6-qubit phase function."""
 
 import revkit
 
+from projectq.cengines import MainEngine
+from projectq.libs.revkit import PermutationOracle, PhaseOracle
+from projectq.meta import Compute, Dagger, Uncompute
+from projectq.ops import All, H, Measure, X
+
 
 # phase function
 def f(a, b, c, d, e, f):
+    """Phase function."""
     return (a and b) ^ (c and d) ^ (e and f)
 
 
