@@ -19,13 +19,12 @@ Tests for projectq.backends._printer.py.
 import pytest
 
 from projectq import MainEngine
+from projectq.backends import _printer
 from projectq.cengines import DummyEngine, InstructionFilter, NotYetMeasuredError
 from projectq.meta import LogicalQubitIDTag
-from projectq.ops import Allocate, Command, H, Measure, NOT, T
+from projectq.ops import NOT, Allocate, Command, H, Measure, T
 from projectq.types import WeakQubitRef
 
-from projectq.backends import _printer
-
 
 def test_command_printer_is_available():
     inline_cmd_printer = _printer.CommandPrinter()
