@@ -13,13 +13,15 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 """
-Contains a compiler engine which counts the number of calls for each type of gate used in a circuit, in addition to
+Contain a compiler engine to calculate resource count used by a quantum circuit.
+
+A resrouce counter compiler engine counts the number of calls for each type of gate used in a circuit, in addition to
 the max. number of active qubits.
 """
 
 from projectq.cengines import BasicEngine, LastEngineException
-from projectq.meta import get_control_count, LogicalQubitIDTag
-from projectq.ops import FlushGate, Deallocate, Allocate, Measure
+from projectq.meta import LogicalQubitIDTag, get_control_count
+from projectq.ops import Allocate, Deallocate, FlushGate, Measure
 from projectq.types import WeakQubitRef
 
 
@@ -43,17 +45,19 @@ class ResourceCounter(BasicEngine):
 
         Sets all statistics to zero.
         """
-        BasicEngine.__init__(self)
+        super().__init__()
         self.gate_counts = {}
         self.gate_class_counts = {}
         self._active_qubits = 0
         self.max_width = 0
         # key: qubit id, depth of this qubit
-        self._depth_of_qubit = dict()
+        self._depth_of_qubit = {}
         self._previous_max_depth = 0
 
     def is_available(self, cmd):
         """
+        Test whether a Command is supported by a compiler engine.
+
         Specialized implementation of is_available: Returns True if the ResourceCounter is the last engine (since it
         can count any command).
 
@@ -70,18 +74,14 @@ class ResourceCounter(BasicEngine):
 
     @property
     def depth_of_dag(self):
-        """
-        Return the depth of the DAG.
-        """
+        """Return the depth of the DAG."""
         if self._depth_of_qubit:
             current_max = max(self._depth_of_qubit.values())
             return max(current_max, self._previous_max_depth)
         return self._previous_max_depth
 
     def _add_cmd(self, cmd):  # pylint: disable=too-many-branches
-        """
-        Add a gate to the count.
-        """
+        """Add a gate to the count."""
         if cmd.gate == Allocate:
             self._active_qubits += 1
             self._depth_of_qubit[cmd.qubits[0][0].id] = 0
@@ -155,9 +155,9 @@ class ResourceCounter(BasicEngine):
 
             return (
                 "Gate class counts:\n    "
-                + "\n    ".join(list(sorted(gate_class_list)))
+                + "\n    ".join(sorted(gate_class_list))
                 + "\n\nGate counts:\n    "
-                + "\n    ".join(list(sorted(gate_list)))
+                + "\n    ".join(sorted(gate_list))
                 + "\n\nMax. width (number of qubits) : "
                 + str(self.max_width)
                 + "."
@@ -166,6 +166,8 @@ class ResourceCounter(BasicEngine):
 
     def receive(self, command_list):
         """
+        Receive a list of commands.
+
         Receive a list of commands from the previous engine, increases the counters of the received commands, and then
         send them on to the next engine.
 
