@@ -16,25 +16,17 @@
 import pytest
 
 from projectq import MainEngine
-from projectq.ops import (
-    All,
-    BasicMathGate,
-    C,
-    Measure,
-    NOT,
-    X,
-    Y,
-)
 from projectq.cengines import (
     AutoReplacer,
     BasicMapperEngine,
     DecompositionRuleSet,
     DummyEngine,
 )
-from ._simulator_test import mapper  # noqa: F401
+from projectq.ops import NOT, All, BasicMathGate, C, Measure, X, Y
 from projectq.types import WeakQubitRef
 
 from ._classical_simulator import ClassicalSimulator
+from ._simulator_test import mapper  # noqa: F401
 
 
 def test_simulator_read_write(mapper):  # noqa: F811
@@ -103,11 +95,11 @@ def test_simulator_bit_repositioning(mapper):  # noqa: F811
 def test_simulator_arithmetic(mapper):  # noqa: F811
     class Offset(BasicMathGate):
         def __init__(self, amount):
-            BasicMathGate.__init__(self, lambda x: (x + amount,))
+            super().__init__(lambda x: (x + amount,))
 
     class Sub(BasicMathGate):
         def __init__(self):
-            BasicMathGate.__init__(self, lambda x, y: (x, y - x))
+            super().__init__(lambda x, y: (x, y - x))
 
     engine_list = []
     if mapper is not None:
