@@ -18,21 +18,20 @@ from copy import deepcopy
 import pytest
 
 from projectq.cengines import DummyEngine
+from projectq.cengines import _linearmapper as lm
 from projectq.meta import LogicalQubitIDTag
 from projectq.ops import (
+    CNOT,
+    QFT,
     Allocate,
     BasicGate,
-    CNOT,
     Command,
     Deallocate,
     FlushGate,
-    QFT,
     X,
 )
 from projectq.types import WeakQubitRef
 
-from projectq.cengines import _linearmapper as lm
-
 
 def test_return_swap_depth():
     swaps = []
@@ -89,7 +88,7 @@ def test_return_new_mapping_allocate_qubits():
     mapper = lm.LinearMapper(num_qubits=2, cyclic=False)
     qb0 = WeakQubitRef(engine=None, idx=0)
     qb1 = WeakQubitRef(engine=None, idx=1)
-    mapper._currently_allocated_ids = set([4])
+    mapper._currently_allocated_ids = {4}
     cmd0 = Command(None, Allocate, ([qb0],))
     cmd1 = Command(None, Allocate, ([qb1],))
     mapper._stored_commands = [cmd0, cmd1]
@@ -100,7 +99,7 @@ def test_return_new_mapping_allocate_qubits():
         stored_commands=mapper._stored_commands,
         current_mapping=mapper.current_mapping,
     )
-    assert mapper._currently_allocated_ids == set([4])
+    assert mapper._currently_allocated_ids == {4}
     assert mapper._stored_commands == [cmd0, cmd1]
     assert len(new_mapping) == 2
     assert 4 in new_mapping and 0 in new_mapping
@@ -172,8 +171,8 @@ def test_return_new_mapping_previous_error():
 def test_process_two_qubit_gate_not_in_segments_test0():
     mapper = lm.LinearMapper(num_qubits=5, cyclic=False)
     segments = [[0, 1]]
-    active_qubits = set([0, 1, 4, 6])
-    neighbour_ids = {0: set([1]), 1: set([0]), 4: set(), 6: set()}
+    active_qubits = {0, 1, 4, 6}
+    neighbour_ids = {0: {1}, 1: {0}, 4: set(), 6: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -186,15 +185,15 @@ def test_process_two_qubit_gate_not_in_segments_test0():
     assert len(segments) == 2
     assert segments[0] == [0, 1]
     assert segments[1] == [4, 6]
-    assert neighbour_ids[4] == set([6])
-    assert neighbour_ids[6] == set([4])
-    assert active_qubits == set([0, 1, 4, 6])
+    assert neighbour_ids[4] == {6}
+    assert neighbour_ids[6] == {4}
+    assert active_qubits == {0, 1, 4, 6}
 
 
 def test_process_two_qubit_gate_not_in_segments_test1():
     mapper = lm.LinearMapper(num_qubits=5, cyclic=False)
     segments = []
-    active_qubits = set([4, 6])
+    active_qubits = {4, 6}
     neighbour_ids = {4: set(), 6: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
@@ -206,7 +205,7 @@ def test_process_two_qubit_gate_not_in_segments_test1():
         neighbour_ids=neighbour_ids,
     )
     assert len(segments) == 0
-    assert active_qubits == set([4])
+    assert active_qubits == {4}
 
 
 @pytest.mark.parametrize("qb0, qb1", [(1, 2), (2, 1)])
@@ -214,8 +213,8 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment(qb0, qb1):
     # add on the right to segment
     mapper = lm.LinearMapper(num_qubits=3, cyclic=False)
     segments = [[0, 1]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set()}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: {1}, 1: {0}, 2: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -226,9 +225,9 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment(qb0, qb1):
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([0, 1, 2])
-    assert neighbour_ids[1] == set([0, 2])
-    assert neighbour_ids[2] == set([1])
+    assert active_qubits == {0, 1, 2}
+    assert neighbour_ids[1] == {0, 2}
+    assert neighbour_ids[2] == {1}
 
 
 @pytest.mark.parametrize("qb0, qb1", [(0, 1), (1, 0)])
@@ -236,8 +235,8 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment2(qb0, qb1):
     # add on the left to segment
     mapper = lm.LinearMapper(num_qubits=3, cyclic=False)
     segments = [[1, 2]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([]), 1: set([2]), 2: set([1])}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: set(), 1: {2}, 2: {1}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -248,17 +247,17 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment2(qb0, qb1):
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([0, 1, 2])
-    assert neighbour_ids[1] == set([0, 2])
-    assert neighbour_ids[0] == set([1])
+    assert active_qubits == {0, 1, 2}
+    assert neighbour_ids[1] == {0, 2}
+    assert neighbour_ids[0] == {1}
 
 
 @pytest.mark.parametrize("qb0, qb1", [(1, 2), (2, 1)])
 def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment_cycle(qb0, qb1):
     mapper = lm.LinearMapper(num_qubits=3, cyclic=True)
     segments = [[0, 1]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set()}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: {1}, 1: {0}, 2: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -269,9 +268,9 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_segment_cycle(qb0, qb1):
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([0, 1, 2])
-    assert neighbour_ids[1] == set([0, 2])
-    assert neighbour_ids[2] == set([1, 0])
+    assert active_qubits == {0, 1, 2}
+    assert neighbour_ids[1] == {0, 2}
+    assert neighbour_ids[2] == {1, 0}
 
 
 @pytest.mark.parametrize("qb0, qb1", [(1, 2), (2, 1)])
@@ -279,8 +278,8 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_seg_cycle2(qb0, qb1):
     # not yet long enough segment for cycle
     mapper = lm.LinearMapper(num_qubits=4, cyclic=True)
     segments = [[0, 1]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set()}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: {1}, 1: {0}, 2: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -291,16 +290,16 @@ def test_process_two_qubit_gate_one_qb_free_one_qb_in_seg_cycle2(qb0, qb1):
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([0, 1, 2])
-    assert neighbour_ids[1] == set([0, 2])
-    assert neighbour_ids[2] == set([1])
+    assert active_qubits == {0, 1, 2}
+    assert neighbour_ids[1] == {0, 2}
+    assert neighbour_ids[2] == {1}
 
 
 def test_process_two_qubit_gate_one_qubit_in_middle_of_segment():
     mapper = lm.LinearMapper(num_qubits=5, cyclic=False)
     segments = []
-    active_qubits = set([0, 1, 2, 3])
-    neighbour_ids = {0: set([1]), 1: set([0, 2]), 2: set([1]), 3: set()}
+    active_qubits = {0, 1, 2, 3}
+    neighbour_ids = {0: {1}, 1: {0, 2}, 2: {1}, 3: set()}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -311,14 +310,14 @@ def test_process_two_qubit_gate_one_qubit_in_middle_of_segment():
         neighbour_ids=neighbour_ids,
     )
     assert len(segments) == 0
-    assert active_qubits == set([0, 2])
+    assert active_qubits == {0, 2}
 
 
 def test_process_two_qubit_gate_both_in_same_segment():
     mapper = lm.LinearMapper(num_qubits=3, cyclic=False)
     segments = [[0, 1, 2]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([1]), 1: set([0, 2]), 2: set([1])}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: {1}, 1: {0, 2}, 2: {1}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -329,14 +328,14 @@ def test_process_two_qubit_gate_both_in_same_segment():
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([1])
+    assert active_qubits == {1}
 
 
 def test_process_two_qubit_gate_already_connected():
     mapper = lm.LinearMapper(num_qubits=3, cyclic=False)
     segments = [[0, 1, 2]]
-    active_qubits = set([0, 1, 2])
-    neighbour_ids = {0: set([1]), 1: set([0, 2]), 2: set([1])}
+    active_qubits = {0, 1, 2}
+    neighbour_ids = {0: {1}, 1: {0, 2}, 2: {1}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -347,7 +346,7 @@ def test_process_two_qubit_gate_already_connected():
         neighbour_ids=neighbour_ids,
     )
     assert segments == [[0, 1, 2]]
-    assert active_qubits == set([0, 1, 2])
+    assert active_qubits == {0, 1, 2}
 
 
 @pytest.mark.parametrize(
@@ -362,8 +361,8 @@ def test_process_two_qubit_gate_already_connected():
 def test_process_two_qubit_gate_combine_segments(qb0, qb1, result_seg):
     mapper = lm.LinearMapper(num_qubits=4, cyclic=False)
     segments = [[0, 1], [2, 3]]
-    active_qubits = set([0, 1, 2, 3, 4])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set([3]), 3: set([2])}
+    active_qubits = {0, 1, 2, 3, 4}
+    neighbour_ids = {0: {1}, 1: {0}, 2: {3}, 3: {2}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -390,8 +389,8 @@ def test_process_two_qubit_gate_combine_segments(qb0, qb1, result_seg):
 def test_process_two_qubit_gate_combine_segments_cycle(qb0, qb1, result_seg):
     mapper = lm.LinearMapper(num_qubits=4, cyclic=True)
     segments = [[0, 1], [2, 3]]
-    active_qubits = set([0, 1, 2, 3, 4])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set([3]), 3: set([2])}
+    active_qubits = {0, 1, 2, 3, 4}
+    neighbour_ids = {0: {1}, 1: {0}, 2: {3}, 3: {2}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -421,8 +420,8 @@ def test_process_two_qubit_gate_combine_segments_cycle2(qb0, qb1, result_seg):
     # Not long enough segment for cyclic
     mapper = lm.LinearMapper(num_qubits=5, cyclic=True)
     segments = [[0, 1], [2, 3]]
-    active_qubits = set([0, 1, 2, 3, 4])
-    neighbour_ids = {0: set([1]), 1: set([0]), 2: set([3]), 3: set([2])}
+    active_qubits = {0, 1, 2, 3, 4}
+    neighbour_ids = {0: {1}, 1: {0}, 2: {3}, 3: {2}}
     mapper._process_two_qubit_gate(
         num_qubits=mapper.num_qubits,
         cyclic=mapper.cyclic,
@@ -450,7 +449,7 @@ def test_process_two_qubit_gate_combine_segments_cycle2(qb0, qb1, result_seg):
 )
 def test_return_new_mapping_from_segments(segments, current_chain, correct_chain, allocated_qubits):
     mapper = lm.LinearMapper(num_qubits=5, cyclic=False)
-    current_mapping = dict()
+    current_mapping = {}
     for pos, logical_id in enumerate(current_chain):
         current_mapping[logical_id] = pos
     mapper.current_mapping = current_mapping
@@ -460,7 +459,7 @@ def test_return_new_mapping_from_segments(segments, current_chain, correct_chain
         allocated_qubits=allocated_qubits,
         current_mapping=mapper.current_mapping,
     )
-    correct_mapping = dict()
+    correct_mapping = {}
     for pos, logical_id in enumerate(correct_chain):
         if logical_id is not None:
             correct_mapping[logical_id] = pos
@@ -478,8 +477,8 @@ def test_return_new_mapping_from_segments(segments, current_chain, correct_chain
 )
 def test_odd_even_transposition_sort_swaps(old_chain, new_chain):
     mapper = lm.LinearMapper(num_qubits=5, cyclic=False)
-    old_map = dict()
-    new_map = dict()
+    old_map = {}
+    new_map = {}
     for pos, logical_id in enumerate(old_chain):
         if logical_id is not None:
             old_map[logical_id] = pos
@@ -510,9 +509,9 @@ def test_send_possible_commands_allocate():
     qb0 = WeakQubitRef(engine=None, idx=0)
     cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[], tags=[])
     mapper._stored_commands = [cmd0]
-    mapper._currently_allocated_ids = set([10])
+    mapper._currently_allocated_ids = {10}
     # not in mapping:
-    mapper.current_mapping = dict()
+    mapper.current_mapping = {}
     assert len(backend.received_commands) == 0
     mapper._send_possible_commands()
     assert len(backend.received_commands) == 0
@@ -525,7 +524,7 @@ def test_send_possible_commands_allocate():
     assert backend.received_commands[0].gate == Allocate
     assert backend.received_commands[0].qubits[0][0].id == 3
     assert backend.received_commands[0].tags == [LogicalQubitIDTag(0)]
-    assert mapper._currently_allocated_ids == set([10, 0])
+    assert mapper._currently_allocated_ids == {10, 0}
 
 
 def test_send_possible_commands_deallocate():
@@ -536,8 +535,8 @@ def test_send_possible_commands_deallocate():
     qb0 = WeakQubitRef(engine=None, idx=0)
     cmd0 = Command(engine=None, gate=Deallocate, qubits=([qb0],), controls=[], tags=[])
     mapper._stored_commands = [cmd0]
-    mapper.current_mapping = dict()
-    mapper._currently_allocated_ids = set([10])
+    mapper.current_mapping = {}
+    mapper._currently_allocated_ids = {10}
     # not yet allocated:
     mapper._send_possible_commands()
     assert len(backend.received_commands) == 0
@@ -551,8 +550,8 @@ def test_send_possible_commands_deallocate():
     assert backend.received_commands[0].qubits[0][0].id == 3
     assert backend.received_commands[0].tags == [LogicalQubitIDTag(0)]
     assert len(mapper._stored_commands) == 0
-    assert mapper.current_mapping == dict()
-    assert mapper._currently_allocated_ids == set([10])
+    assert mapper.current_mapping == {}
+    assert mapper._currently_allocated_ids == {10}
 
 
 def test_send_possible_commands_keep_remaining_gates():
@@ -581,7 +580,7 @@ def test_send_possible_commands_not_cyclic():
     qb1 = WeakQubitRef(engine=None, idx=1)
     qb2 = WeakQubitRef(engine=None, idx=2)
     qb3 = WeakQubitRef(engine=None, idx=3)
-    mapper._currently_allocated_ids = set([0, 1, 2, 3])
+    mapper._currently_allocated_ids = {0, 1, 2, 3}
     cmd0 = Command(None, CNOT, qubits=([qb0],), controls=[qb2])
     cmd1 = Command(None, CNOT, qubits=([qb1],), controls=[qb2])
     cmd2 = Command(None, CNOT, qubits=([qb1],), controls=[qb3])
@@ -609,7 +608,7 @@ def test_send_possible_commands_cyclic():
     qb1 = WeakQubitRef(engine=None, idx=1)
     qb2 = WeakQubitRef(engine=None, idx=2)
     qb3 = WeakQubitRef(engine=None, idx=3)
-    mapper._currently_allocated_ids = set([0, 1, 2, 3])
+    mapper._currently_allocated_ids = {0, 1, 2, 3}
     cmd0 = Command(None, CNOT, qubits=([qb0],), controls=[qb1])
     cmd1 = Command(None, CNOT, qubits=([qb1],), controls=[qb2])
     cmd2 = Command(None, CNOT, qubits=([qb1],), controls=[qb3])
@@ -649,7 +648,7 @@ def test_run_and_receive():
     mapper.receive([cmd_flush])
     assert mapper._stored_commands == []
     assert len(backend.received_commands) == 7
-    assert mapper._currently_allocated_ids == set([0, 2])
+    assert mapper._currently_allocated_ids == {0, 2}
     assert mapper.current_mapping == {0: 2, 2: 0} or mapper.current_mapping == {
         0: 0,
         2: 2,
@@ -657,7 +656,7 @@ def test_run_and_receive():
     cmd6 = Command(None, X, qubits=([qb0],), controls=[qb2])
     mapper.storage = 1
     mapper.receive([cmd6])
-    assert mapper._currently_allocated_ids == set([0, 2])
+    assert mapper._currently_allocated_ids == {0, 2}
     assert mapper._stored_commands == []
     assert len(mapper.current_mapping) == 2
     assert 0 in mapper.current_mapping
