@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #   Copyright 2017 ProjectQ-Framework (www.projectq.ch)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,6 +15,4 @@
 
 from ._decomposition_rule import DecompositionRule, ThisIsNotAGateClassError
 from ._decomposition_rule_set import DecompositionRuleSet
-from ._replacer import (AutoReplacer,
-                        InstructionFilter,
-                        NoGateDecompositionError)
+from ._replacer import AutoReplacer, InstructionFilter, NoGateDecompositionError
