@@ -13,9 +13,8 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-"""Functions to plot a histogram of measured data"""
+"""Functions to plot a histogram of measured data."""
 
-from __future__ import print_function
 import matplotlib.pyplot as plt
 
 from projectq.backends import Simulator
