@@ -13,7 +13,7 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-"""RevKit support for permutation oracles"""
+"""RevKit support for permutation oracles."""
 
 from projectq.ops import BasicGate
 
@@ -22,7 +22,7 @@ from ._utils import _exec
 
 class PermutationOracle:  # pylint: disable=too-few-public-methods
     """
-    Synthesizes a permutation using RevKit.
+    Synthesize a permutation using RevKit.
 
     Given a permutation over `2**q` elements (starting from 0), this class
     helps to automatically find a reversible circuit over `q` qubits that
@@ -36,16 +36,15 @@ class PermutationOracle:  # pylint: disable=too-few-public-methods
 
     def __init__(self, permutation, **kwargs):
         """
-        Initializes a permutation oracle.
+        Initialize a permutation oracle.
 
         Args:
             permutation (list<int>): Permutation (starting from 0).
 
         Keyword Args:
-            synth: A RevKit synthesis command which creates a reversible
-                   circuit based on a reversible truth table (e.g.,
-                   ``revkit.tbs`` or ``revkit.dbs``).  Can also be a
-                   nullary lambda that calls several RevKit commands.
+            synth: A RevKit synthesis command which creates a reversible circuit based on a reversible truth table
+                   (e.g., ``revkit.tbs`` or ``revkit.dbs``).  Can also be a nullary lambda that calls several RevKit
+                   commands.
                    **Default:** ``revkit.tbs``
         """
         self.permutation = permutation
@@ -55,11 +54,10 @@ class PermutationOracle:  # pylint: disable=too-few-public-methods
 
     def __or__(self, qubits):
         """
-        Applies permutation to qubits (and synthesizes circuit).
+        Apply permutation to qubits (and synthesizes circuit).
 
         Args:
-            qubits (tuple<Qureg>): Qubits to which the permutation is being
-                                   applied.
+            qubits (tuple<Qureg>): Qubits to which the permutation is being applied.
         """
         try:
             import revkit  # pylint: disable=import-outside-toplevel
@@ -88,10 +86,8 @@ class PermutationOracle:  # pylint: disable=too-few-public-methods
         _exec(revkit.to_projectq(mct=True), qs)
 
     def _check_permutation(self):
-        """
-        Checks whether permutation is valid.
-        """
+        """Check whether permutation is valid."""
         # permutation must start from 0, has no duplicates and all elements are
         # consecutive
-        if sorted(list(set(self.permutation))) != list(range(len(self.permutation))):
+        if sorted(set(self.permutation)) != list(range(len(self.permutation))):
             raise AttributeError("Invalid permutation (does it start from 0?)")
