@@ -22,10 +22,15 @@ efficient code. It includes, e.g.,
 * Dagger (with Dagger(eng): ...)
 """
 
-from ._dirtyqubit import DirtyQubitTag
-from ._loop import LoopTag, Loop
-from ._compute import Compute, Uncompute, CustomUncompute, ComputeTag, UncomputeTag
-from ._control import Control, get_control_count, has_negative_control, canonical_ctrl_state
+from ._compute import Compute, ComputeTag, CustomUncompute, Uncompute, UncomputeTag
+from ._control import (
+    Control,
+    canonical_ctrl_state,
+    get_control_count,
+    has_negative_control,
+)
 from ._dagger import Dagger
-from ._util import insert_engine, drop_engine_after
+from ._dirtyqubit import DirtyQubitTag
 from ._logicalqubit import LogicalQubitIDTag
+from ._loop import Loop, LoopTag
+from ._util import drop_engine_after, insert_engine
