@@ -14,9 +14,7 @@
 #   limitations under the License.
 """Tests for projectq.meta._dirtyqubit.py"""
 
-from projectq.meta import ComputeTag
-
-from projectq.meta import _dirtyqubit
+from projectq.meta import ComputeTag, _dirtyqubit
 
 
 def test_dirty_qubit_tag():
