@@ -12,12 +12,11 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-"""
-Defines LogicalQubitIDTag to annotate a MeasureGate for mapped qubits.
-"""
+
+"""Definition of LogicalQubitIDTag to annotate a MeasureGate for mapped qubits."""
 
 
-class LogicalQubitIDTag:
+class LogicalQubitIDTag:  # pylint: disable=too-few-public-methods
     """
     LogicalQubitIDTag for a mapped qubit to annotate a MeasureGate.
 
@@ -26,10 +25,9 @@ class LogicalQubitIDTag:
     """
 
     def __init__(self, logical_qubit_id):
+        """Initialize a LogicalQubitIDTag object."""
         self.logical_qubit_id = logical_qubit_id
 
     def __eq__(self, other):
+        """Equal operator."""
         return isinstance(other, LogicalQubitIDTag) and self.logical_qubit_id == other.logical_qubit_id
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
