@@ -16,25 +16,33 @@
 """ProjectQ module containing all basic gates (operations)"""
 
 from ._basics import (
-    NotMergeable,
-    NotInvertible,
     BasicGate,
-    MatrixGate,
-    SelfInverseGate,
+    BasicMathGate,
+    BasicPhaseGate,
     BasicRotationGate,
     ClassicalInstructionGate,
     FastForwardingGate,
-    BasicMathGate,
-    BasicPhaseGate,
+    MatrixGate,
+    NotInvertible,
+    NotMergeable,
+    SelfInverseGate,
 )
-from ._command import apply_command, Command, CtrlAll, IncompatibleControlState
-from ._metagates import DaggeredGate, get_inverse, is_identity, ControlledGate, C, Tensor, All
+from ._command import Command, CtrlAll, IncompatibleControlState, apply_command
 from ._gates import *
+from ._metagates import (
+    All,
+    C,
+    ControlledGate,
+    DaggeredGate,
+    Tensor,
+    get_inverse,
+    is_identity,
+)
+from ._qaagate import QAA
 from ._qftgate import QFT, QFTGate
+from ._qpegate import QPE
 from ._qubit_operator import QubitOperator
 from ._shortcuts import *
+from ._state_prep import StatePreparation
 from ._time_evolution import TimeEvolution
 from ._uniformly_controlled_rotation import UniformlyControlledRy, UniformlyControlledRz
-from ._state_prep import StatePreparation
-from ._qpegate import QPE
-from ._qaagate import QAA
