@@ -13,17 +13,16 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-"""Contains the definition of the QFT gate"""
+"""Definition of the QFT gate."""
 
 from ._basics import BasicGate
 
 
 class QFTGate(BasicGate):
-    """
-    Quantum Fourier Transform gate.
-    """
+    """Quantum Fourier Transform gate."""
 
     def __str__(self):
+        """Return a string representation of the object."""
         return "QFT"
 
 
