@@ -13,20 +13,20 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 """
-Defines a few shortcuts for certain gates such as
+A few shortcuts for certain gates.
+
+These include:
 * CNOT = C(NOT)
 * CRz = C(Rz)
 * Toffoli = C(NOT,2) = C(CNOT)
 """
 
-from ._metagates import C
 from ._gates import NOT, Rz, Z
+from ._metagates import C
 
 
 def CRz(angle):
-    """
-    Shortcut for C(Rz(angle), n_qubits=1).
-    """
+    """Shortcut for C(Rz(angle), n_qubits=1)."""
     return C(Rz(angle), n_qubits=1)
 
 
