@@ -12,12 +12,11 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-"""
-Registers a decomposition to for a CNOT gate in terms of CZ and Hadamard.
-"""
+
+"""Registers a decomposition to for a CNOT gate in terms of CZ and Hadamard."""
 
 from projectq.cengines import DecompositionRule
-from projectq.meta import Compute, get_control_count, Uncompute
+from projectq.meta import Compute, Uncompute, get_control_count
 from projectq.ops import CZ, H, X
 
 
