@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #   Copyright 2017 ProjectQ-Framework (www.projectq.ch)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,7 +12,6 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-
 """
 Registers a decomposition rule for global phases.
 
@@ -23,17 +23,14 @@ from projectq.meta import get_control_count
 from projectq.ops import Ph
 
 
-def _decompose_PhNoCtrl(cmd):
-    """ Throw out global phases (no controls). """
-    pass
+def _decompose_PhNoCtrl(cmd):  # pylint: disable=invalid-name,unused-argument
+    """Throw out global phases (no controls)."""
 
 
-def _recognize_PhNoCtrl(cmd):
-    """ Recognize global phases (no controls). """
+def _recognize_PhNoCtrl(cmd):  # pylint: disable=invalid-name
+    """Recognize global phases (no controls)."""
     return get_control_count(cmd) == 0
 
 
 #: Decomposition rules
-all_defined_decomposition_rules = [
-    DecompositionRule(Ph, _decompose_PhNoCtrl, _recognize_PhNoCtrl)
-]
+all_defined_decomposition_rules = [DecompositionRule(Ph, _decompose_PhNoCtrl, _recognize_PhNoCtrl)]
