@@ -16,15 +16,14 @@
 #   Module uses ideas from "Basic circuit compilation techniques for an
 #   ion-trap quantum machine" by Dmitri Maslov (2017) at
 #   https://iopscience.iop.org/article/10.1088/1367-2630/aa5e47
-"""
-Registers a decomposition for the H gate into an Ry and Rx gate.
-"""
+
+"""Register a decomposition for the H gate into an Ry and Rx gate."""
 
 import math
 
 from projectq.cengines import DecompositionRule
 from projectq.meta import get_control_count
-from projectq.ops import Ph, Rx, Ry, H
+from projectq.ops import H, Ph, Rx, Ry
 
 
 def _decompose_h2rx_M(cmd):  # pylint: disable=invalid-name
