@@ -17,6 +17,7 @@ import cmath
 
 import pytest
 
+import projectq.setups.decompositions.qubitop2onequbit as qubitop2onequbit
 from projectq import MainEngine
 from projectq.backends import Simulator
 from projectq.cengines import (
@@ -26,11 +27,9 @@ from projectq.cengines import (
     InstructionFilter,
 )
 from projectq.meta import Control
-from projectq.ops import All, Measure, Ph, QubitOperator, X, Y, Z, Command
+from projectq.ops import All, Command, Measure, Ph, QubitOperator, X, Y, Z
 from projectq.types import WeakQubitRef
 
-import projectq.setups.decompositions.qubitop2onequbit as qubitop2onequbit
-
 
 def test_recognize():
     saving_backend = DummyEngine(save_commands=True)
