@@ -21,21 +21,19 @@ def test_ibm_cnot_mapper_in_cengines(monkeypatch):
     import projectq.setups.ibm
 
     def mock_show_devices(*args, **kwargs):
-        connections = set(
-            [
-                (0, 1),
-                (1, 0),
-                (1, 2),
-                (1, 3),
-                (1, 4),
-                (2, 1),
-                (2, 3),
-                (2, 4),
-                (3, 1),
-                (3, 4),
-                (4, 3),
-            ]
-        )
+        connections = {
+            (0, 1),
+            (1, 0),
+            (1, 2),
+            (1, 3),
+            (1, 4),
+            (2, 1),
+            (2, 3),
+            (2, 4),
+            (3, 1),
+            (3, 4),
+            (4, 3),
+        }
         return {
             'ibmq_burlington': {
                 'coupling_map': connections,
@@ -67,21 +65,19 @@ def test_ibm_errors(monkeypatch):
     import projectq.setups.ibm
 
     def mock_show_devices(*args, **kwargs):
-        connections = set(
-            [
-                (0, 1),
-                (1, 0),
-                (1, 2),
-                (1, 3),
-                (1, 4),
-                (2, 1),
-                (2, 3),
-                (2, 4),
-                (3, 1),
-                (3, 4),
-                (4, 3),
-            ]
-        )
+        connections = {
+            (0, 1),
+            (1, 0),
+            (1, 2),
+            (1, 3),
+            (1, 4),
+            (2, 1),
+            (2, 3),
+            (2, 4),
+            (3, 1),
+            (3, 4),
+            (4, 3),
+        }
         return {'ibmq_imaginary': {'coupling_map': connections, 'version': '0.0.0', 'nq': 6}}
 
     monkeypatch.setattr(projectq.setups.ibm, "show_devices", mock_show_devices)
