@@ -19,16 +19,16 @@ import projectq.libs.math
 import projectq.setups.decompositions
 from projectq.backends._sim._simulator_test import sim
 from projectq.cengines import (
-    MainEngine,
     AutoReplacer,
     DecompositionRuleSet,
     InstructionFilter,
     LocalOptimizer,
+    MainEngine,
     TagRemover,
 )
 from projectq.libs.math import MultiplyByConstantModN
 from projectq.meta import Control
-from projectq.ops import All, BasicMathGate, get_inverse, H, Measure, QFT, Swap, X
+from projectq.ops import QFT, All, BasicMathGate, H, Measure, Swap, X, get_inverse
 
 rule_set = DecompositionRuleSet(modules=(projectq.libs.math, projectq.setups.decompositions))
 
